pocketpose.graphics.pose_visualizer - PocketPose 0.0.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `pocketpose.graphics.pose_visualizer`

## Module Contents

### Classes

`PoseVisualizer` |

### Functions

`get_visualizer`(name, *args, **kwargs) |

class pocketpose.graphics.pose_visualizer.PoseVisualizer(kpts_name, radius: float = 5.0, thickness: int = 3, kpt_thr: float = 0.3, draw_bbox: bool = False)
  generate_colors()
  generate_skeleton()
  _visualize(image, keypoints) → PIL.Image.Image
  visualize(image_path, keypoints) → PIL.Image.Image
  visualize_numpy(image, keypoints) → numpy.ndarray
  visualize_multiple(image_path, keypoints_list) → PIL.Image.Image

pocketpose.graphics.pose_visualizer.get_visualizer(name, *args, **kwargs)